@@ -518,11 +518,13 @@ struct _GFileIface
   
   GFileMonitor*      (*monitor_dir)         (GFile                  *file,
 					     GFileMonitorFlags       flags,
-					     GCancellable           *cancellable);
+					     GCancellable           *cancellable,
+					     GError                **error);
 
   GFileMonitor*      (*monitor_file)        (GFile                  *file,
 					     GFileMonitorFlags       flags,
-					     GCancellable           *cancellable);
+					     GCancellable           *cancellable,
+					     GError                **error);
 
 };
 
@@ -610,6 +612,8 @@ void                    g_file_replace_async              (GFile
 GFileOutputStream *     g_file_replace_finish             (GFile                      *file,
 							   GAsyncResult               *res,
 							   GError                    **error);
+gboolean                g_file_query_exists               (GFile                      *file,
+							   GCancellable               *cancellable);
 GFileInfo *             g_file_query_info                 (GFile                      *file,
 							   const char                 *attributes,
 							   GFileQueryInfoFlags         flags,
@@ -629,9 +633,17 @@ GFileInfo *             g_file_query_filesystem_info      (GFile
 							   const char                 *attributes,
 							   GCancellable               *cancellable,
 							   GError                    **error);
-GMount *                g_file_find_enclosing_mount      (GFile                      *file,
-                                                          GCancellable               *cancellable,
-                                                          GError                    **error);
+GMount *                g_file_find_enclosing_mount       (GFile                      *file,
+                                                           GCancellable               *cancellable,
+                                                           GError                    **error);
+void                    g_file_find_enclosing_mount_async (GFile                      *file,
+							   int                         io_priority,
+							   GCancellable               *cancellable,
+							   GAsyncReadyCallback         callback,
+							   gpointer                    user_data);
+GMount *                g_file_find_enclosing_mount_finish (GFile                     *file,
+							    GAsyncResult              *res,
+							    GError                   **error);
 GFileEnumerator *       g_file_enumerate_children         (GFile                      *file,
 							   const char                 *attributes,
 							   GFileQueryInfoFlags         flags,
@@ -794,10 +806,12 @@ gboolean                g_file_copy_attributes            (GFile
 
 GFileMonitor*           g_file_monitor_directory          (GFile                  *file,
 							   GFileMonitorFlags       flags,
-							   GCancellable           *cancellable);
+							   GCancellable           *cancellable,
+							   GError                **error);
 GFileMonitor*           g_file_monitor_file               (GFile                  *file,
 							   GFileMonitorFlags       flags,
-							   GCancellable           *cancellable);
+							   GCancellable           *cancellable,
+							   GError                **error);
 
 
 /* Utilities */
