@@ -629,6 +629,12 @@ param_string_validate (GParamSpec *pspec,
       
       if (sspec->cset_first && !strchr (sspec->cset_first, string[0]))
 	{
+          if (value->data[1].v_uint & G_VALUE_NOCOPY_CONTENTS)
+            {
+              value->data[0].v_pointer = g_strdup (string);
+              string = value->data[0].v_pointer;
+              value->data[1].v_uint &= ~G_VALUE_NOCOPY_CONTENTS;
+            }
 	  string[0] = sspec->substitutor;
 	  changed++;
 	}
@@ -636,24 +642,35 @@ param_string_validate (GParamSpec *pspec,
 	for (s = string + 1; *s; s++)
 	  if (!strchr (sspec->cset_nth, *s))
 	    {
+              if (value->data[1].v_uint & G_VALUE_NOCOPY_CONTENTS)
+                {
+                  value->data[0].v_pointer = g_strdup (string);
+                  s = (gchar*) value->data[0].v_pointer + (s - string);
+                  string = value->data[0].v_pointer;
+                  value->data[1].v_uint &= ~G_VALUE_NOCOPY_CONTENTS;
+                }
 	      *s = sspec->substitutor;
 	      changed++;
 	    }
     }
   if (sspec->null_fold_if_empty && string && string[0] == 0)
     {
-      g_free (value->data[0].v_pointer);
+      if (!(value->data[1].v_uint & G_VALUE_NOCOPY_CONTENTS))
+        g_free (value->data[0].v_pointer);
+      else
+        value->data[1].v_uint &= ~G_VALUE_NOCOPY_CONTENTS;
       value->data[0].v_pointer = NULL;
       changed++;
       string = value->data[0].v_pointer;
     }
   if (sspec->ensure_non_null && !string)
     {
+      value->data[1].v_uint &= ~G_VALUE_NOCOPY_CONTENTS;
       value->data[0].v_pointer = g_strdup ("");
       changed++;
       string = value->data[0].v_pointer;
     }
-  
+
   return changed;
 }
 
@@ -1453,17 +1470,17 @@ g_param_spec_types_init (void)
   /* G_TYPE_PARAM_GTYPE
    */
   {
-    GType value_type = G_TYPE_GTYPE;
     GParamSpecTypeInfo pspec_info = {
       sizeof (GParamSpecGType),	/* instance_size */
       0,			/* n_preallocs */
       param_gtype_init,		/* instance_init */
-      value_type,		/* value_type */
+      0xdeadbeef,		/* value_type, assigned further down */
       NULL,			/* finalize */
       param_gtype_set_default,	/* value_set_default */
       param_gtype_validate,	/* value_validate */
       param_gtype_values_cmp,	/* values_cmp */
     };
+    pspec_info.value_type = G_TYPE_GTYPE;
     type = g_param_type_register_static (g_intern_static_string ("GParamGType"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_GTYPE);
